package com.logicbig.example;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import java.util.Arrays;
import java.util.List;

@Component
public class ExampleClient {

    @Autowired
    private EmployeeRepository repo;


    public void run() {
        List<Employee> employees = createEmployees();
        repo.saveAll(employees);

        System.out.println(" -- finding all employees --");
        Iterable<Employee> all = repo.findAll();
        all.forEach(System.out::println);

        System.out.println(" -- finding the employee with max salary --");
        Employee emp = repo.findTopByOrderBySalaryDesc();
        System.out.println(emp);

        System.out.println(" -- finding the employee with min salary --");
        emp = repo.findTopByOrderBySalaryAsc();
        System.out.println(emp);

        System.out.println(" -- finding the top 3 employees with max salary --");
        List<Employee> list = repo.findTop3ByOrderBySalaryDesc();
        list.stream().forEach(System.out::println);

        System.out.println(" -- finding the top 3 employees with min salary --");
        list = repo.findTop3ByOrderBySalaryAsc();
        list.stream().forEach(System.out::println);

        System.out.println(" -- finding the first 2 employees with salary 3000 --");
        list = repo.findFirst2BySalary(3000);
        list.stream().forEach(System.out::println);

        System.out.println(" -- finding the top 2 employees with max salary in IT dept --");
        list = repo.findFirst2ByDeptOrderBySalaryDesc("IT");
        list.stream().forEach(System.out::println);
    }

    private List<Employee> createEmployees() {
        return Arrays.asList(
                Employee.create("Diana", "Admin", 3000),
                Employee.create("Mike", "Sale", 1000),
                Employee.create("Rose", "IT", 4000),
                Employee.create("Sara", "Admin", 3500),
                Employee.create("Tanaka", "IT", 3000),
                Employee.create("Charlie", "IT", 2500)
        );
    }
}